@@ -144,7 +144,7 @@ static gboolean
 gst_image_sequence_src_uri_set_uri (GstURIHandler * handler, const gchar * uri,
     GError ** err)
 {
-  gchar *hostname = NULL, *location = NULL, *tmp;
+  gchar *hostname = NULL, *location = NULL, *path, *tmp;
   gboolean ret = FALSE;
   GstImageSequenceSrc *self = GST_IMAGE_SEQUENCE_SRC (handler);
   GstUri *ruri = gst_uri_from_string (uri);
@@ -160,9 +160,11 @@ gst_image_sequence_src_uri_set_uri (GstURIHandler * handler, const gchar * uri,
   LOCK (self);
   g_clear_pointer (&self->uri, gst_uri_unref);
   self->uri = ruri;
-  tmp = gst_filename_to_uri (gst_uri_get_path (ruri), err);
+  path = gst_uri_get_path (ruri);
+  tmp = gst_filename_to_uri (path, err);
   location = g_filename_from_uri (tmp, &hostname, err);
   g_free (tmp);
+  g_free (path);
   query = gst_uri_get_query_table (ruri);
   if (!location || (err != NULL && *err != NULL)) {
     GST_WARNING_OBJECT (self, "Invalid URI '%s' for imagesequencesrc: %s", uri,
@@ -229,6 +231,8 @@ gst_image_sequence_src_uri_handler_init (gpointer g_iface, gpointer iface_data)
       0, "imagesequencesrc element");
 G_DEFINE_TYPE_WITH_CODE (GstImageSequenceSrc, gst_image_sequence_src,
     GST_TYPE_PUSH_SRC, _do_init);
+GST_ELEMENT_REGISTER_DEFINE (imagesequencesrc, "imagesequencesrc",
+    GST_RANK_NONE, gst_image_sequence_src_get_type ());
 
 static gboolean
 is_seekable (GstBaseSrc * src)
@@ -527,6 +531,8 @@ gst_image_sequence_src_set_caps (GstImageSequenceSrc * self, GstCaps * caps)
   gst_pad_set_caps (GST_BASE_SRC_PAD (self), new_caps);
 
   GST_DEBUG_OBJECT (self, "Setting new caps: %" GST_PTR_FORMAT, new_caps);
+
+  gst_caps_unref (new_caps);
 }
 
 /* Call with LOCK */
@@ -604,7 +610,7 @@ gst_image_sequence_src_create (GstPushSrc * src, GstBuffer ** buffer)
   if (!ret)
     goto handle_error;
 
-  buf = gst_buffer_new_wrapped_full (0, data, size, 0, size, NULL, g_free);
+  buf = gst_buffer_new_wrapped (data, size);
 
   if (!self->caps) {
     GstCaps *caps;
